From 58bb04ea840a5988354b855eea0f22c80d0a936b Mon Sep 17 00:00:00 2001
From: Aditya Vidyadhar Kamath <Aditya.Kamath1@ibm.com>
Date: Mon, 20 Nov 2023 01:01:35 -0600
Subject: [PATCH] Fix AIX thr!= NULL assertion failure during fork.

In AIX, while we followed the child process and detach on fork was on we hit this assertion failure.

The reason for the same was GDB core trying to switch to a child thread with tid not set that does not
exist, since child's ptid was changed to ptid_t (pid, 0, tid) in sync_threadlists() as it was threaded.

This patch is a fix for the same.
---
 gdb/aix-thread.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/gdb/aix-thread.c b/gdb/aix-thread.c
index 945b7f6c697..03030dc9351 100644
--- a/gdb/aix-thread.c
+++ b/gdb/aix-thread.c
@@ -927,7 +927,11 @@ sync_threadlists (pid_t pid)
 	      /* This is to make the main process thread now look
 		 like a thread.  */
 
-	      if (gptid.is_pid ())
+		  if (pcount == gcount == 1)
+		{
+		    gi++;pi++;
+		}
+	    else if (gptid.is_pid ())
 		{
 		  tp = proc_target->find_thread (gptid);
 		  thread_change_ptid (proc_target, gptid, pptid);
-- 
2.41.0

